(set-background "level4.png")
(set-skin "skin.png")
(set-bonus-time 80000)
(load "../utils.scm")

(block-rect 192 90 4 1 "light-brown")
(block-rect 192 108 4 1 "superstrong")
(block-rect 64 224 4 1 "superstrong")
(block-rect 320 224 4 1 "superstrong")
(block-rect 320 206 4 1 "dark-brown")
(block-rect 64 206 4 1 "dark-brown")
(block-rect 0 0 3 6 "superstrong")
(block-rect 416 0 3 6 "superstrong")

